@@ -33,10 +33,15 @@
 
 extern int no_var_bindings;
 
-AsnOid atmAddressStatus;
+//AsnOid atmAddressStatus;
 
 Message *create_poll_message(void);
 Message *create_set_message(void);
 Message *create_coldstart_message(void);
+Message *create_va_getnext_message( int, ... );
+Message *create_va_get_message( int, ... );
+Message *create_getnext_message( AsnOid );
+Message *create_get_message( AsnOid );
+void free_message( Message *m );
 
 #endif
