@@ -37,6 +37,7 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <sys/ioctl.h>
+#include <time.h>
 
 #include <atm.h>
 #include <atmsap.h>
@@ -116,7 +117,7 @@ void init_conn_params(struct atm_sap *sap, struct atm_qos *qos,
         int i, sdu;
         char qos_text[MAX_ATM_QOS_LEN + 1];
 
-        diag(COMPONENT, DIAG_DEBUG, "init_conn_params, conn_type %x\n", conn_type);
+        diag(COMPONENT, DIAG_DEBUG, "init_conn_params, conn_type %x", conn_type);
 
         memset(qos, 0, sizeof(struct atm_qos));
         memset(sap, 0, sizeof(struct atm_sap));
@@ -135,7 +136,7 @@ void init_conn_params(struct atm_sap *sap, struct atm_qos *qos,
                 qos->txtp.max_sdu = sdu;
                 break;
         default:
-                diag(COMPONENT, DIAG_ERROR, "unknown conn_type %x\n", conn_type);
+                diag(COMPONENT, DIAG_ERROR, "unknown conn_type %x", conn_type);
                 break;
         }
         
@@ -146,7 +147,7 @@ void init_conn_params(struct atm_sap *sap, struct atm_qos *qos,
         if (get_verbosity(COMPONENT) >= DIAG_DEBUG) {
                 if (qos2text(qos_text, sizeof(qos_text), qos, 0) < 0)
                         sprintf(qos_text, "<bad qos>");
-                diag(COMPONENT, DIAG_DEBUG, "init_conn_params, QoS '%s'\n", qos_text);
+                diag(COMPONENT, DIAG_DEBUG, "init_conn_params, QoS '%s'", qos_text);
         }
 
         /* No Broadband High Layer Information in LANE. */
@@ -192,19 +193,19 @@ static int get_socket(struct sockaddr_atmsvc *listen_addr,
 
         s = socket(PF_ATMSVC, SOCK_DGRAM, 0);
         if (s < 0) {
-                diag(COMPONENT, DIAG_ERROR, "socket creation failure: %s\n",
+                diag(COMPONENT, DIAG_ERROR, "socket creation failure: %s",
                      strerror(errno));
                 return -1;
         }
-        diag(COMPONENT, DIAG_DEBUG, "get_socket: got fd %d\n", s);
+        diag(COMPONENT, DIAG_DEBUG, "get_socket: got fd %d", s);
         
         if (setsockopt(s, SOL_ATM, SO_ATMQOS, qos, sizeof(struct atm_qos)) < 0) {
-                diag(COMPONENT, DIAG_ERROR, "get_socket: setsockopt SO_ATMQOS: %s\n", strerror(errno));
+                diag(COMPONENT, DIAG_ERROR, "get_socket: setsockopt SO_ATMQOS: %s", strerror(errno));
                 close(s);
                 return -1;
         }
         if (setsockopt(s, SOL_ATM, SO_ATMSAP, sap, sizeof(struct atm_sap)) < 0) {
-                diag(COMPONENT, DIAG_ERROR, "setup_svc setsockop(SO_ATMSAP)\n");
+                diag(COMPONENT, DIAG_ERROR, "setup_svc setsockop(SO_ATMSAP)");
                 close(s);
                 return -1;
         }
@@ -214,7 +215,7 @@ static int get_socket(struct sockaddr_atmsvc *listen_addr,
                 return s;
         ret = bind(s, (struct sockaddr *)listen_addr, sizeof(struct sockaddr_atmsvc));
         if (ret < 0) {
-                diag(COMPONENT, DIAG_ERROR, "bind error: %s\n", strerror(errno));
+                diag(COMPONENT, DIAG_ERROR, "bind error: %s", strerror(errno));
                 close(s);
                 return -1;
         }
@@ -223,15 +224,6 @@ static int get_socket(struct sockaddr_atmsvc *listen_addr,
 }
 
 
-/*
- * You need to check this if setup_svc() returns NULL
- */
-#if 0
-        if (is_data_direct(&sap->blli[0])) {
-                /* Try to remove possible entry in kernel */
-                delete_addr(conn->atm_address);
-        }
-#endif
 /* Does an active open to dst_addr using pre-filled
  * parameters in sap and qos.
  * If listen_addr is non NULL, binds to it.
@@ -246,45 +238,29 @@ Conn_t *setup_svc(struct sockaddr_atmsvc *dst_addr,
         int s, ret;
         char buff[MAX_ATM_ADDR_LEN+1];
 
-        diag(COMPONENT, DIAG_DEBUG, "Outgoing call setup\n");
+        diag(COMPONENT, DIAG_DEBUG, "Outgoing call setup");
         
-        /* The code below is commented out due to the following scenario:
-           We have made a connection to another LEC and our address was
-           numerically lower than theirs (LANEv2 8.1.13).
-           The other end has also connected us, but we must not use that
-           VCC.
-           However, if the connection we made gets closed, we can not open
-           it again since a connection to the destination LEC already exists.
-        */
-#if 0
-        /* We don't create connection to an entity where we already have
-           a connection. */
-        if (conn_already_exists(dst_addr->sas_addr.prv, NULL) &&
-            is_data_direct(&sap->blli[0]))
-                return NULL;
-#endif
-
         dst_addr->sas_family = AF_ATMSVC;
         listen_addr->sas_family = AF_ATMSVC;
         
         switch(sap->blli[0].l3.tr9577.snap[4]) { /* Kludge.  Eh? */
         case CONTROL_CONN:
-                diag(COMPONENT, DIAG_DEBUG, "LE Control SVC setup\n");
+                diag(COMPONENT, DIAG_DEBUG, "LE Control SVC setup");
                 break;
         case DATA_DIRECT_8023:
-                diag(COMPONENT, DIAG_DEBUG, "Data direct 802.3\n");
+                diag(COMPONENT, DIAG_DEBUG, "Data direct 802.3");
                 break;
         case DATA_DIRECT_8025:
-                diag(COMPONENT, DIAG_DEBUG, "Data direct 802.5\n");
+                diag(COMPONENT, DIAG_DEBUG, "Data direct 802.5");
                 break;
         case MCAST_CONN_8023:
-                diag(COMPONENT, DIAG_DEBUG, "Multicast 802.3\n");
+                diag(COMPONENT, DIAG_DEBUG, "Multicast 802.3");
                 break;
         case MCAST_CONN_8025:
-                diag(COMPONENT, DIAG_DEBUG, "Multicast 802.5\n");
+                diag(COMPONENT, DIAG_DEBUG, "Multicast 802.5");
                 break;
         default:
-                diag(COMPONENT, DIAG_ERROR, "Unknown codepoint in svc setup\n");
+                diag(COMPONENT, DIAG_ERROR, "Unknown codepoint in svc setup");
         }
  
         s = get_socket(listen_addr, sap, qos);
@@ -297,10 +273,10 @@ Conn_t *setup_svc(struct sockaddr_atmsvc *dst_addr,
         if (is_data_direct(&sap->blli[0])) {
                 ret = fcntl(s, F_GETFL);
                 if (ret < 0) {
-                        diag(COMPONENT, DIAG_ERROR, "fcntl(s, F_GETFL)\n");
+                        diag(COMPONENT, DIAG_ERROR, "fcntl(s, F_GETFL)");
                         close(s);
                 } else if (fcntl(s, F_SETFL, ret|O_NONBLOCK) < 0) {
-                        diag(COMPONENT, DIAG_ERROR, "fcntl(s, F_SETFL, x|O_NONBLOCK)\n");
+                        diag(COMPONENT, DIAG_ERROR, "fcntl(s, F_SETFL, x|O_NONBLOCK)");
                         close(s);
                         return NULL;
                 }
@@ -308,13 +284,13 @@ Conn_t *setup_svc(struct sockaddr_atmsvc *dst_addr,
 
         ret = connect(s, (struct sockaddr *)dst_addr, sizeof(struct sockaddr_atmsvc));
         if (ret < 0 && errno != EINPROGRESS) {
-                diag(COMPONENT, DIAG_ERROR, "connect error: %s\n", strerror(errno));
+                diag(COMPONENT, DIAG_ERROR, "connect error: %s", strerror(errno));
                 close(s);
                 return NULL;
         }
 
         conn = list_add_conn(dst_addr->sas_addr.prv);
-        diag(COMPONENT, DIAG_DEBUG, "Conn:%p\n", conn);
+        diag(COMPONENT, DIAG_DEBUG, "Conn:%p", conn);
         if (conn == NULL) {
                 close(s);
                 return NULL;
@@ -348,7 +324,7 @@ int create_data_listen(void)
 
         lec_params.data_listen = create_listensocket(&addr, &sap, &qos);
         if (lec_params.data_listen == NULL) {
-                diag(COMPONENT, DIAG_FATAL, "Could not create listen socket for incoming Data Direct VCCs\n");
+                diag(COMPONENT, DIAG_FATAL, "Could not create listen socket for incoming Data Direct VCCs");
                 return -1;
         }
 
@@ -375,7 +351,7 @@ int create_data_svc(unsigned char *atm_addr, int codepoint)
 
         conn = setup_svc(&dst_addr, &my_addr, &sap, &qos);
         if (conn == NULL) {
-                diag(COMPONENT, DIAG_ERROR, "Could not create Data Direct VCC\n");
+                diag(COMPONENT, DIAG_ERROR, "Could not create Data Direct VCC");
                 delete_addr(dst_addr.sas_addr.prv);
                 return -1;
         }
@@ -393,28 +369,28 @@ Conn_t *create_listensocket(struct sockaddr_atmsvc *listen_addr,
         int fd, ret;
         Conn_t *conn;
 
-        diag(COMPONENT, DIAG_DEBUG, "conn_create_listensocket\n");
+        diag(COMPONENT, DIAG_DEBUG, "conn_create_listensocket");
         
         fd = get_socket(listen_addr, sap, qos);
         if (fd < 0) return NULL;
         
-        ret = listen(fd, 5);
+        ret = listen(fd, 16);
         if (ret != 0) {
-                diag(COMPONENT, DIAG_DEBUG, "Listen failed: %s\n", strerror(errno));
+                diag(COMPONENT, DIAG_DEBUG, "Listen failed: %s", strerror(errno));
                 close(fd);
                 return NULL;
         }
         
         conn = list_add_conn(NULL);
         if (conn == NULL) {
-                diag(COMPONENT, DIAG_ERROR, "List_add_conn failed\n");
+                diag(COMPONENT, DIAG_ERROR, "List_add_conn failed");
                 close(fd);    
                 return NULL;
         }
 
         conn->type = LISTENING;
         conn->fd = fd;
-        diag(COMPONENT, DIAG_DEBUG, "Listen socket created blli:%2.2x %2.2x fd: %d\n",
+        diag(COMPONENT, DIAG_DEBUG, "Listen socket created blli:%2.2x %2.2x fd: %d",
              sap->blli[0].l3.tr9577.snap[3],
              sap->blli[0].l3.tr9577.snap[4],
              conn->fd);
@@ -433,12 +409,12 @@ Conn_t *accept_conn(Conn_t *conn)
         int fd;
         char buff[MAX_ATM_ADDR_LEN+1];
 
-        diag(COMPONENT, DIAG_DEBUG, "Accepting connection on fd %d\n", conn->fd);
+        diag(COMPONENT, DIAG_DEBUG, "Accepting connection on fd %d", conn->fd);
         len = sizeof(addr);
         fd = accept(conn->fd, (struct sockaddr *)&addr, &len);
-        diag(COMPONENT, DIAG_DEBUG, "accept returned %d\n", fd);
+        diag(COMPONENT, DIAG_DEBUG, "accept returned %d", fd);
         if (fd < 0) {
-                diag(COMPONENT, DIAG_ERROR, "accept: %s\n", strerror(errno));
+                diag(COMPONENT, DIAG_ERROR, "accept: %s", strerror(errno));
                 return NULL;
         }
         if (atm2text(buff, sizeof(buff), (struct sockaddr *)&addr, A2T_PRETTY | A2T_NAME | A2T_LOCAL) < 0)
@@ -457,19 +433,21 @@ Conn_t *accept_conn(Conn_t *conn)
         return new;
 }
 
-/* Close all connections, important or not.
+/* Close all connections, except the kernel socket.
  */
 void close_connections(void)
 {
         Conn_t *conn, *next;
 
         for(conn = connlist; conn; conn = next) {
-                diag(COMPONENT, DIAG_DEBUG, "Destroying:%p fd:%d type:%d\n",
-                     conn, conn->fd, conn->type);
-                next = conn->next;
-                close(conn->fd);
-                list_remove_conn(conn);
-                free(conn);
+		next = conn->next;
+		if (conn->type != KERNEL_SOCK) {
+			diag(COMPONENT, DIAG_DEBUG, "Destroying:%p fd:%d type:%d",
+			     conn, conn->fd, conn->type);
+			close(conn->fd);
+			list_remove_conn(conn);
+			free(conn);
+		}
         }
 
         return;
@@ -486,7 +464,7 @@ int close_connection(Conn_t *conn)
         int bad = 0;
         Conn_t *mcast;
 
-        diag(COMPONENT, DIAG_DEBUG, "close_connection %p\n", conn);
+        diag(COMPONENT, DIAG_DEBUG, "close_connection %p", conn);
 
         if (conn == lec_params.kernel ||
             conn == lec_params.ctrl_direct  ||
@@ -517,32 +495,39 @@ int close_connection(Conn_t *conn)
  */
 static int handle_accept(Conn_t *conn)
 {
-        Conn_t *new;
+        Conn_t *new, *existing = NULL;
         struct atmlec_ioc ioc;
         
         new = accept_conn(conn);
         if (new == NULL) return -1;
 
         if (conn == lec_params.mcast_listen) {
-                diag(COMPONENT, DIAG_DEBUG, "Multicast Forward VCC accepted\n");
+                diag(COMPONENT, DIAG_DEBUG, "Multicast Forward VCC accepted");
                 ioc.receive = 2;
         } else {
-                diag(COMPONENT, DIAG_DEBUG, "Data Direct VCC accepted\n");
+                diag(COMPONENT, DIAG_DEBUG, "Data Direct VCC accepted");
                 ioc.receive = 0;
-                if (conn_already_exists(new->atm_address, new) &&
-                    memcmp(lec_params.c1n_my_atm_addr, new->atm_address,  ATM_ESA_LEN) < 0) {
-                        diag(COMPONENT, DIAG_DEBUG, "Using it only to receive, spec 8.1.1\n");
-                        ioc.receive = 1;
-                }
+                if ((existing = conn_already_exists(new->atm_address, new)) &&
+		    /* is calling address > called address */
+		    (memcmp(new->atm_address, lec_params.c1n_my_atm_addr, ATM_ESA_LEN) > 0)) {
+			diag(COMPONENT, DIAG_DEBUG, "Using it only to receive, spec 8.1.13");
+			ioc.receive = 1;
+			existing = NULL;
+		}
         }
         memcpy(ioc.atm_addr, new->atm_address, ATM_ESA_LEN);
         ioc.dev_num = lec_params.itf_num;
-        diag(COMPONENT, DIAG_DEBUG, "Attaching a new VCC, fd %d\n", new->fd);
+        diag(COMPONENT, DIAG_DEBUG, "Attaching a new VCC, fd %d", new->fd);
         if (ioctl(new->fd, ATMLEC_DATA, &ioc) < 0) {
-                diag(COMPONENT, DIAG_ERROR, "VCC attach failed: ioctl: %s\n", strerror(errno));
+                diag(COMPONENT, DIAG_ERROR, "VCC attach failed: ioctl: %s", strerror(errno));
                 return -1;
         }
 
+	if (existing && existing->status == CONNECTED) {
+		diag(COMPONENT, DIAG_DEBUG, "Closing old data direct, fd %d", existing->fd);
+		close_connection(existing);
+	}
+
         return 0;
 }
 
@@ -558,11 +543,11 @@ static int handle_data(Conn_t *conn)
 
         retval = recv_frame(conn, buff, sizeof(buff));
         if (retval < 0) {
-                diag(COMPONENT, DIAG_ERROR, "handle_data: read: %s\n", strerror(errno));
+                diag(COMPONENT, DIAG_ERROR, "handle_data: read: %s", strerror(errno));
                 return (close_connection(conn));
         }
         if (retval == 0) {
-                diag(COMPONENT, DIAG_DEBUG, "fd %d, Data or Multicast VCC closed\n", conn->fd);
+                diag(COMPONENT, DIAG_DEBUG, "fd %d, Data or Multicast VCC closed", conn->fd);
                 return (close_connection(conn));
         }
 
@@ -597,7 +582,7 @@ int check_connections(fd_set *fds)
                                 return -1;
                         break;
                 default:
-                        diag(COMPONENT, DIAG_ERROR, "check_connections: bad_type '%s'\n",
+                        diag(COMPONENT, DIAG_ERROR, "check_connections: bad_type '%s'",
                              get_type_string(conn->type));
                         break;
                 }
@@ -618,7 +603,7 @@ static int handle_connect(Conn_t *conn)
         struct atmlec_msg msg;
         struct atmlec_ioc ioc;
 
-        diag(COMPONENT, DIAG_DEBUG, "handle_connect: completing fd %d\n", conn->fd);
+        diag(COMPONENT, DIAG_DEBUG, "handle_connect: completing fd %d", conn->fd);
         /* this seems to be common method in Linux-ATM
          * making sure that nonblocking connect was
          * completed successfully
@@ -626,23 +611,30 @@ static int handle_connect(Conn_t *conn)
         conn->status = CONNECTED;
         retval = connect(conn->fd, (struct sockaddr *)&dummy, sizeof(struct sockaddr_atmsvc));
         if (retval < 0) {
-                diag(COMPONENT, DIAG_DEBUG, "handle_connect: connect: %s\n", strerror(errno));
+                diag(COMPONENT, DIAG_DEBUG, "handle_connect: connect: %s", strerror(errno));
                 delete_addr(conn->atm_address);
                 close_connection(conn);
                 return 0;
         }
 
-        send_ready_ind(conn);
-
         memcpy(ioc.atm_addr, conn->atm_address, ATM_ESA_LEN);
         ioc.dev_num = lec_params.itf_num;
         ioc.receive = 0;
-        diag(COMPONENT, DIAG_DEBUG, "Attaching a new active VCC, fd %d\n", conn->fd);
+        diag(COMPONENT, DIAG_DEBUG, "Attaching a new active VCC, fd %d", conn->fd);
+	if (conn_already_exists(conn->atm_address, conn) &&
+	    /* is calling address > called address */
+	    memcmp(lec_params.c1n_my_atm_addr, conn->atm_address, ATM_ESA_LEN) > 0) {
+		diag(COMPONENT, DIAG_DEBUG, "Receive only, spec 8.1.13 -- Closing");
+                close_connection(conn);
+                return 0;
+	}
         if (ioctl(conn->fd, ATMLEC_DATA, &ioc) < 0) {
-                diag(COMPONENT, DIAG_ERROR, "VCC attach failed: ioctl: %s\n", strerror(errno));
+                diag(COMPONENT, DIAG_ERROR, "VCC attach failed: ioctl: %s", strerror(errno));
                 return -1;
         }
 
+        send_ready_ind(conn);
+
         memset(&msg, 0, sizeof(struct atmlec_msg));
         msg.type = l_flush_tran_id;
         memcpy(msg.content.normal.atm_addr, conn->atm_address, ATM_ESA_LEN);
@@ -683,17 +675,17 @@ int send_frame(Conn_t *conn, void *frame, int length)
         struct frame_hdr *hdr;
         int ret;
 
-        diag(COMPONENT, DIAG_DEBUG, "send_frame: fd:%d len:%ld\n", conn->fd, length);
+        diag(COMPONENT, DIAG_DEBUG, "send_frame: fd:%d len:%ld", conn->fd, length);
         hdr = (struct frame_hdr *)frame;
         if (hdr->opcode == htons(READY_QUERY) ||
             hdr->opcode == htons(READY_IND))
-                diag(COMPONENT, DIAG_DEBUG, "%s\n", opcode2text(hdr->opcode));
+                diag(COMPONENT, DIAG_DEBUG, "%s", opcode2text(hdr->opcode));
         else 
                 display_frame(frame);
 
         ret = write(conn->fd, frame, length);
         if (ret < 0) {
-                diag(COMPONENT, DIAG_ERROR, "send_frame: write: %s\n", strerror(errno));
+                diag(COMPONENT, DIAG_ERROR, "send_frame: write: %s", strerror(errno));
                 return -1;
         } 
 
@@ -707,15 +699,15 @@ int recv_frame(Conn_t *conn, void *buff, int length)
 {
         int ret;
 
-        diag(COMPONENT, DIAG_DEBUG, "recv_frame: fd:%d\n", conn->fd);
+        diag(COMPONENT, DIAG_DEBUG, "recv_frame: fd:%d", conn->fd);
         ret = read(conn->fd, buff, length);
         if (ret < 0) {
-                diag(COMPONENT, DIAG_ERROR, "Read failed: %s\n", strerror(errno));
+                diag(COMPONENT, DIAG_ERROR, "Read failed: %s", strerror(errno));
                 return -1;
         } 
 
 #if 0
-        diag(COMPONENT, DIAG_DEBUG, "recv_frame: read %d bytes\n", ret);
+        diag(COMPONENT, DIAG_DEBUG, "recv_frame: read %d bytes", ret);
         if (get_verbosity(COMPONENT) >= DIAG_DEBUG) {
                 int i;
                 for (i = 0; i < 11; i++)
@@ -741,7 +733,7 @@ void random_delay(void)
         tv.tv_sec  = (millis - (millis % 1000)) / 1000;
         tv.tv_usec = (millis % 1000) * 1000;
         
-        diag(COMPONENT, DIAG_DEBUG, "random_delay: sleeping %d.%d seconds\n", tv.tv_sec, tv.tv_usec);
+        diag(COMPONENT, DIAG_DEBUG, "random_delay: sleeping %d.%d seconds", tv.tv_sec, tv.tv_usec);
         (void)select(0, NULL, NULL, NULL, &tv);
         
         return;
@@ -793,7 +785,7 @@ int conn_set_kernel_socket(int fd)
 
         conn = list_add_conn(NULL);
         if (conn == NULL) {
-                diag(COMPONENT, DIAG_ERROR, "conn_set_kernel_socket: list_add_conn failed\n");
+                diag(COMPONENT, DIAG_ERROR, "conn_set_kernel_socket: list_add_conn failed");
                 return -1;
         }
         conn->type = KERNEL_SOCK;
@@ -825,7 +817,7 @@ static Conn_t *list_add_conn(unsigned char *atm_addr)
         if (connlist)
                 connlist->previous = conn;
         connlist = conn;
-        diag(COMPONENT, DIAG_DEBUG, "Added conn:%p\n", conn);
+        diag(COMPONENT, DIAG_DEBUG, "Added conn:%p", conn);
 
         return conn;
 }
@@ -854,7 +846,7 @@ static void list_remove_conn(Conn_t *conn)
                 connlist = conn->next;
         if (conn->next)
                 conn->next->previous = conn->previous;  
-        diag(COMPONENT, DIAG_DEBUG, "Connlist: %p\n", connlist);
+        diag(COMPONENT, DIAG_DEBUG, "Connlist: %p", connlist);
         conn->next=conn->previous= NULL;
         
         return;
