@@ -1,24 +1,22 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+/* A Bison parser, made by GNU Bison 2.4.3.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
-   Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2009, 2010 Free Software Foundation, Inc.
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +27,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +45,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.3"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,57 +53,26 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     TOK_BREAK = 258,
-     TOK_CASE = 259,
-     TOK_DEF = 260,
-     TOK_DEFAULT = 261,
-     TOK_LENGTH = 262,
-     TOK_MULTI = 263,
-     TOK_RECOVER = 264,
-     TOK_ABORT = 265,
-     TOK_ID = 266,
-     TOK_INCLUDE = 267,
-     TOK_STRING = 268
-   };
-#endif
-/* Tokens.  */
-#define TOK_BREAK 258
-#define TOK_CASE 259
-#define TOK_DEF 260
-#define TOK_DEFAULT 261
-#define TOK_LENGTH 262
-#define TOK_MULTI 263
-#define TOK_RECOVER 264
-#define TOK_ABORT 265
-#define TOK_ID 266
-#define TOK_INCLUDE 267
-#define TOK_STRING 268
-
-
-
-
 /* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
 #line 1 "ql_y.y"
 
 /* ql.y - Q.2931 data structures description language */
 
 /* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
 
-#if HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -125,6 +92,8 @@ FIELD *def = NULL;
 static STRUCTURE *structures = NULL;
 static const char *abort_id; /* indicates abort flag */
 
+void yyerror(const char *s);
+int yylex(void);
 
 static NAME_LIST *get_name_list(const char *name)
 {
@@ -158,8 +127,10 @@ static NAME_LIST *get_name_list(const char *name)
 	    *walk = 0;
 	if (*start == ':') {
 	    if (!(searching = strcmp(start+1,name)))
+	    {
 		if (found) yyerror("multiple entries");
 		else found = 1;
+	    }
 	    continue;
 	}
 	if (searching) continue;
@@ -235,6 +206,9 @@ static FIELD *copy_block(FIELD *orig_field)
 
 
 
+/* Line 189 of yacc.c  */
+#line 211 "ql_y.c"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -253,10 +227,49 @@ static FIELD *copy_block(FIELD *orig_field)
 # define YYTOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     TOK_BREAK = 258,
+     TOK_CASE = 259,
+     TOK_DEF = 260,
+     TOK_DEFAULT = 261,
+     TOK_LENGTH = 262,
+     TOK_MULTI = 263,
+     TOK_RECOVER = 264,
+     TOK_ABORT = 265,
+     TOK_ID = 266,
+     TOK_INCLUDE = 267,
+     TOK_STRING = 268
+   };
+#endif
+/* Tokens.  */
+#define TOK_BREAK 258
+#define TOK_CASE 259
+#define TOK_DEF 260
+#define TOK_DEFAULT 261
+#define TOK_LENGTH 262
+#define TOK_MULTI 263
+#define TOK_RECOVER 264
+#define TOK_ABORT 265
+#define TOK_ID 266
+#define TOK_INCLUDE 267
+#define TOK_STRING 268
+
+
+
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 139 "ql_y.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 139 "ql_y.y"
+
     const char *str;
     int num;
     FIELD *field;
@@ -264,22 +277,23 @@ typedef union YYSTYPE
     VALUE_LIST *list;
     TAG *tag;
     NAME_LIST *nlist;
-}
-/* Line 187 of yacc.c.  */
-#line 270 "ql_y.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 285 "ql_y.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 283 "ql_y.c"
+/* Line 264 of yacc.c  */
+#line 297 "ql_y.c"
 
 #ifdef short
 # undef short
@@ -329,7 +343,7 @@ typedef short int yytype_int16;
 #define YYSIZE_MAXIMUM ((YYSIZE_T) -1)
 
 #ifndef YY_
-# if YYENABLE_NLS
+# if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
 #   define YY_(msgid) dgettext ("bison-runtime", msgid)
@@ -354,14 +368,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -442,9 +456,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -478,12 +492,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -580,9 +594,9 @@ static const yytype_uint16 yyrline[] =
 {
        0,   164,   164,   175,   176,   184,   185,   189,   203,   203,
      213,   231,   236,   244,   247,   255,   279,   282,   289,   301,
-     319,   322,   330,   340,   343,   351,   354,   361,   367,   374,
-     380,   391,   394,   401,   404,   411,   414,   432,   431,   455,
-     458,   475,   474,   498,   501,   508,   511
+     321,   324,   332,   342,   345,   353,   356,   363,   369,   376,
+     382,   393,   396,   403,   406,   413,   416,   434,   433,   457,
+     460,   477,   476,   500,   503,   510,   513
 };
 #endif
 
@@ -595,7 +609,7 @@ static const char *const yytname[] =
   "TOK_DEFAULT", "TOK_LENGTH", "TOK_MULTI", "TOK_RECOVER", "TOK_ABORT",
   "TOK_ID", "TOK_INCLUDE", "TOK_STRING", "'='", "'{'", "'}'", "'<'", "'-'",
   "'>'", "'@'", "','", "':'", "$accept", "all", "includes", "structures",
-  "structure", "rep_block", "@1", "block", "fields", "field", "opt_break",
+  "structure", "rep_block", "$@1", "block", "fields", "field", "opt_break",
   "field_cont", "opt_pos", "decimal", "opt_more", "opt_val", "value",
   "opt_recover", "opt_name_list", "tags", "@2", "rep_tags", "@3", "opt_id",
   "list", 0
@@ -735,9 +749,18 @@ static const yytype_uint8 yystos[] =
 
 /* Like YYERROR except do call yyerror.  This remains here temporarily
    to ease the transition to the new meaning of YYERROR, for GCC.
-   Once GCC version 2 has supplanted version 1, this can go.  */
+   Once GCC version 2 has supplanted version 1, this can go.  However,
+   YYFAIL appears to be in use.  Nevertheless, it is formally deprecated
+   in Bison 2.4.2's NEWS entry, where a plan to phase it out is
+   discussed.  */
 
 #define YYFAIL		goto yyerrlab
+#if defined YYFAIL
+  /* This is here to suppress warnings from the GCC cpp's
+     -Wunused-macros.  Normally we don't worry about that warning, but
+     some users do, and we want to make it easy for users to remove
+     YYFAIL uses, which will produce warnings from Bison 2.5.  */
+#endif
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
@@ -794,7 +817,7 @@ while (YYID (0))
    we won't break user code: when these are the locations we know.  */
 
 #ifndef YY_LOCATION_PRINT
-# if YYLTYPE_IS_TRIVIAL
+# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
 #  define YY_LOCATION_PRINT(File, Loc)			\
      fprintf (File, "%d.%d-%d.%d",			\
 	      (Loc).first_line, (Loc).first_column,	\
@@ -905,17 +928,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -949,11 +975,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1233,10 +1259,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1252,11 +1276,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1264,9 +1287,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1290,14 +1313,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1305,51 +1353,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1379,7 +1404,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1387,7 +1411,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1410,9 +1433,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1423,7 +1445,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1433,6 +1454,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1441,16 +1465,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1482,20 +1506,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1535,6 +1555,8 @@ yyreduce:
   switch (yyn)
     {
         case 2:
+
+/* Line 1464 of yacc.c  */
 #line 165 "ql_y.y"
     {
 	    STRUCTURE *walk;
@@ -1547,6 +1569,8 @@ yyreduce:
     break;
 
   case 4:
+
+/* Line 1464 of yacc.c  */
 #line 177 "ql_y.y"
     {
 	    to_c("#%s\n",(yyvsp[(1) - (2)].str));
@@ -1556,6 +1580,8 @@ yyreduce:
     break;
 
   case 7:
+
+/* Line 1464 of yacc.c  */
 #line 190 "ql_y.y"
     {
 	    STRUCTURE *n;
@@ -1570,6 +1596,8 @@ yyreduce:
     break;
 
   case 8:
+
+/* Line 1464 of yacc.c  */
 #line 203 "ql_y.y"
     {
 	    abort_id = NULL;
@@ -1577,6 +1605,8 @@ yyreduce:
     break;
 
   case 9:
+
+/* Line 1464 of yacc.c  */
 #line 207 "ql_y.y"
     {
 	    (yyval.field) = (yyvsp[(2) - (2)].field);
@@ -1584,6 +1614,8 @@ yyreduce:
     break;
 
   case 10:
+
+/* Line 1464 of yacc.c  */
 #line 214 "ql_y.y"
     {
 	    STRUCTURE *walk;
@@ -1605,6 +1637,8 @@ yyreduce:
     break;
 
   case 11:
+
+/* Line 1464 of yacc.c  */
 #line 232 "ql_y.y"
     {
 	    (yyval.field) = (yyvsp[(2) - (3)].field);
@@ -1613,6 +1647,8 @@ yyreduce:
     break;
 
   case 12:
+
+/* Line 1464 of yacc.c  */
 #line 237 "ql_y.y"
     {
 	    (yyval.field) = NULL;
@@ -1621,6 +1657,8 @@ yyreduce:
     break;
 
   case 13:
+
+/* Line 1464 of yacc.c  */
 #line 244 "ql_y.y"
     {
 	    (yyval.field) = NULL;
@@ -1628,6 +1666,8 @@ yyreduce:
     break;
 
   case 14:
+
+/* Line 1464 of yacc.c  */
 #line 248 "ql_y.y"
     {
 	    (yyval.field) = (yyvsp[(1) - (2)].field);
@@ -1636,6 +1676,8 @@ yyreduce:
     break;
 
   case 15:
+
+/* Line 1464 of yacc.c  */
 #line 256 "ql_y.y"
     {
 	    TAG *walk;
@@ -1660,6 +1702,8 @@ yyreduce:
     break;
 
   case 16:
+
+/* Line 1464 of yacc.c  */
 #line 279 "ql_y.y"
     {
 	    (yyval.num) = 0;
@@ -1667,6 +1711,8 @@ yyreduce:
     break;
 
   case 17:
+
+/* Line 1464 of yacc.c  */
 #line 283 "ql_y.y"
     {
 	    (yyval.num) = 1;
@@ -1674,6 +1720,8 @@ yyreduce:
     break;
 
   case 18:
+
+/* Line 1464 of yacc.c  */
 #line 290 "ql_y.y"
     {
 	    (yyval.field) = alloc_t(FIELD);
@@ -1689,6 +1737,8 @@ yyreduce:
     break;
 
   case 19:
+
+/* Line 1464 of yacc.c  */
 #line 302 "ql_y.y"
     {
 	    (yyval.field) = alloc_t(FIELD);
@@ -1697,9 +1747,11 @@ yyreduce:
 	    (yyval.field)->pos = (yyvsp[(2) - (5)].num);
 	    (yyval.field)->flush = !(yyvsp[(3) - (5)].num);
 	    if ((yyval.field)->pos == -1)
+	    {
 		if ((yyval.field)->size & 7)
 		    yyerror("position required for small fields");
 		else (yyval.field)->pos = 0;
+	    }
 	    (yyval.field)->value = (yyvsp[(5) - (5)].value);
 	    (yyval.field)->structure = NULL;
 	    (yyval.field)->next = NULL;
@@ -1707,14 +1759,18 @@ yyreduce:
     break;
 
   case 20:
-#line 319 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 321 "ql_y.y"
     {
 	    (yyval.num) = -1;
 	}
     break;
 
   case 21:
-#line 323 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 325 "ql_y.y"
     {
 	    (yyval.num) = (yyvsp[(2) - (2)].num)-1;
 	    if ((yyval.num) < 0 || (yyval.num) > 7) yyerror("invalid position");
@@ -1722,7 +1778,9 @@ yyreduce:
     break;
 
   case 22:
-#line 331 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 333 "ql_y.y"
     {
 	    char *end;
 
@@ -1732,14 +1790,18 @@ yyreduce:
     break;
 
   case 23:
-#line 340 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 342 "ql_y.y"
     {
 	    (yyval.num) = 0;
 	}
     break;
 
   case 24:
-#line 344 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 346 "ql_y.y"
     {
 	    if (strcmp((yyvsp[(2) - (2)].str),"more")) yyerror("\"more\" expected");
 	    (yyval.num) = 1;
@@ -1747,21 +1809,27 @@ yyreduce:
     break;
 
   case 25:
-#line 351 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 353 "ql_y.y"
     {
 	    (yyval.value) = NULL;
 	}
     break;
 
   case 26:
-#line 355 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 357 "ql_y.y"
     {
 	    (yyval.value) = (yyvsp[(2) - (2)].value);
 	}
     break;
 
   case 27:
-#line 362 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 364 "ql_y.y"
     {
 	    (yyval.value) = alloc_t(VALUE);
 	    (yyval.value)->type = vt_id;
@@ -1770,7 +1838,9 @@ yyreduce:
     break;
 
   case 28:
-#line 368 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 370 "ql_y.y"
     {
 	    (yyval.value) = alloc_t(VALUE);
 	    (yyval.value)->type = vt_case;
@@ -1780,7 +1850,9 @@ yyreduce:
     break;
 
   case 29:
-#line 375 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 377 "ql_y.y"
     {
 	    (yyval.value) = alloc_t(VALUE);
 	    (yyval.value)->type = vt_multi;
@@ -1789,7 +1861,9 @@ yyreduce:
     break;
 
   case 30:
-#line 381 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 383 "ql_y.y"
     {
 	    (yyval.value) = alloc_t(VALUE);
 	    (yyval.value)->type = vt_length;
@@ -1800,42 +1874,54 @@ yyreduce:
     break;
 
   case 31:
-#line 391 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 393 "ql_y.y"
     {
 	    (yyval.str) = NULL;
 	}
     break;
 
   case 32:
-#line 395 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 397 "ql_y.y"
     {
 	    (yyval.str) = (yyvsp[(2) - (2)].str);
 	}
     break;
 
   case 33:
-#line 401 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 403 "ql_y.y"
     {
 	    (yyval.nlist) = NULL;
 	}
     break;
 
   case 34:
-#line 405 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 407 "ql_y.y"
     {
 	    (yyval.nlist) = get_name_list((yyvsp[(1) - (1)].str));
 	}
     break;
 
   case 35:
-#line 411 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 413 "ql_y.y"
     {
 	    (yyval.tag) = NULL;
 	}
     break;
 
   case 36:
-#line 415 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 417 "ql_y.y"
     {
 	    (yyval.tag) = alloc_t(TAG);
 	    (yyval.tag)->deflt = 1;
@@ -1855,7 +1941,9 @@ yyreduce:
     break;
 
   case 37:
-#line 432 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 434 "ql_y.y"
     {
 	    (yyval.tag) = alloc_t(TAG);
 	    (yyval.tag)->abort_id = abort_id;
@@ -1863,7 +1951,9 @@ yyreduce:
     break;
 
   case 38:
-#line 437 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 439 "ql_y.y"
     {
 	    (yyval.tag) = (yyvsp[(5) - (6)].tag);
 	    (yyval.tag)->deflt = 0;
@@ -1882,14 +1972,18 @@ yyreduce:
     break;
 
   case 39:
-#line 455 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 457 "ql_y.y"
     {
 	    (yyval.tag) = NULL;
 	}
     break;
 
   case 40:
-#line 459 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 461 "ql_y.y"
     {
 	    (yyval.tag) = alloc_t(TAG);
 	    (yyval.tag)->deflt = 1;
@@ -1908,7 +2002,9 @@ yyreduce:
     break;
 
   case 41:
-#line 475 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 477 "ql_y.y"
     {
 	    (yyval.tag) = alloc_t(TAG);
 	    (yyval.tag)->abort_id = abort_id;
@@ -1916,7 +2012,9 @@ yyreduce:
     break;
 
   case 42:
-#line 480 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 482 "ql_y.y"
     {
 	    (yyval.tag) = (yyvsp[(5) - (6)].tag);
 	    (yyval.tag)->deflt = 0;
@@ -1935,28 +2033,36 @@ yyreduce:
     break;
 
   case 43:
-#line 498 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 500 "ql_y.y"
     {
 	    (yyval.str) = NULL;
 	}
     break;
 
   case 44:
-#line 502 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 504 "ql_y.y"
     {
 	    (yyval.str) = (yyvsp[(2) - (2)].str);
 	}
     break;
 
   case 45:
-#line 508 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 510 "ql_y.y"
     {
 	    (yyval.list) = NULL;
 	}
     break;
 
   case 46:
-#line 512 "ql_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 514 "ql_y.y"
     {
 	    (yyval.list) = alloc_t(VALUE_LIST);
 	    (yyval.list)->value = (yyvsp[(2) - (3)].str);
@@ -1965,8 +2071,9 @@ yyreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1970 "ql_y.c"
+
+/* Line 1464 of yacc.c  */
+#line 2077 "ql_y.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1977,7 +2084,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -2042,7 +2148,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -2059,7 +2165,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2116,9 +2222,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -2143,7 +2246,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2154,7 +2257,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
