@@ -1,24 +1,22 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+/* A Bison parser, made by GNU Bison 2.4.3.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
-   Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2009, 2010 Free Software Foundation, Inc.
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +27,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +45,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.3"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,11 +53,100 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
+/* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
+#line 1 "cfg_y.y"
+
+/* cfg.y - configuration language */
+
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
+
+#if HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <stdlib.h>
+#include <string.h>
+#include <ctype.h>
+#include <limits.h>
+#include <stdlib.h>
+
+#include "atm.h"
+#include "atmd.h"
+
+#include "proto.h"
+#include "io.h"
+#include "trace.h"
+#include "policy.h"
+
+
+static RULE *rule;
+static SIG_ENTITY *curr_sig = &_entity;
+
+void yyerror(const char *s);
+void yywarn(const char *s);
+int yylex(void);
+
+static int hex2num(char digit)
+{
+    if (isdigit(digit)) return digit-'0';
+    if (islower(digit)) return toupper(digit)-'A'+10;
+    return digit-'A'+10;
+}
+
+
+static void put_address(char *address)
+{
+    char *mask;
+
+    mask = strchr(address,'/');
+    if (mask) *mask++ = 0;
+    if (text2atm(address,(struct sockaddr *) &rule->addr,sizeof(rule->addr),
+      T2A_SVC | T2A_WILDCARD | T2A_NAME | T2A_LOCAL) < 0) {
+	yyerror("invalid address");
+	return;
+    }
+    if (!mask) rule->mask = -1;
+    else rule->mask = strtol(mask,NULL,10);
+    add_rule(rule);
+}
+
+
+
+/* Line 189 of yacc.c  */
+#line 130 "cfg_y.c"
+
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef YYERROR_VERBOSE
+# undef YYERROR_VERBOSE
+# define YYERROR_VERBOSE 1
+#else
+# define YYERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
+
+
 /* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
@@ -145,102 +232,33 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 1 "cfg_y.y"
-
-/* cfg.y - configuration language */
-
-/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
-
-#if HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <string.h>
-#include <ctype.h>
-#include <limits.h>
-#include <stdlib.h>
-
-#include "atm.h"
-#include "atmd.h"
-
-#include "proto.h"
-#include "io.h"
-#include "trace.h"
-#include "policy.h"
-
-
-static RULE *rule;
-static SIG_ENTITY *curr_sig = &_entity;
-
-
-static int hex2num(char digit)
-{
-    if (isdigit(digit)) return digit-'0';
-    if (islower(digit)) return toupper(digit)-'A'+10;
-    return digit-'A'+10;
-}
-
-
-static void put_address(char *address)
-{
-    char *mask;
-
-    mask = strchr(address,'/');
-    if (mask) *mask++ = 0;
-    if (text2atm(address,(struct sockaddr *) &rule->addr,sizeof(rule->addr),
-      T2A_SVC | T2A_WILDCARD | T2A_NAME | T2A_LOCAL) < 0) {
-	yyerror("invalid address");
-	return;
-    }
-    if (!mask) rule->mask = -1;
-    else rule->mask = strtol(mask,NULL,10);
-    add_rule(rule);
-}
-
-
-
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
-
-/* Enabling verbose error messages.  */
-#ifdef YYERROR_VERBOSE
-# undef YYERROR_VERBOSE
-# define YYERROR_VERBOSE 1
-#else
-# define YYERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
-#endif
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 54 "cfg_y.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 58 "cfg_y.y"
+
     int num;
     char *str;
     struct sockaddr_atmpvc pvc;
-}
-/* Line 187 of yacc.c.  */
-#line 231 "cfg_y.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 250 "cfg_y.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 244 "cfg_y.c"
+/* Line 264 of yacc.c  */
+#line 262 "cfg_y.c"
 
 #ifdef short
 # undef short
@@ -290,7 +308,7 @@ typedef short int yytype_int16;
 #define YYSIZE_MAXIMUM ((YYSIZE_T) -1)
 
 #ifndef YY_
-# if YYENABLE_NLS
+# if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
 #   define YY_(msgid) dgettext ("bison-runtime", msgid)
@@ -315,14 +333,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -403,9 +421,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -439,12 +457,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -551,14 +569,14 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,    75,    75,    78,    79,    82,    83,   107,   111,   112,
-     113,   114,   115,   120,   119,   141,   142,   145,   146,   150,
-     154,   155,   159,   163,   177,   184,   185,   188,   189,   193,
-     194,   197,   198,   202,   203,   206,   207,   211,   212,   215,
-     216,   220,   221,   224,   225,   229,   235,   239,   248,   257,
-     266,   275,   280,   284,   292,   296,   300,   305,   309,   316,
-     320,   325,   329,   336,   339,   346,   350,   354,   358,   362,
-     369,   373,   377,   384,   389,   388,   397,   401,   408,   413
+       0,    79,    79,    82,    83,    86,    87,   111,   115,   116,
+     117,   118,   119,   124,   123,   145,   146,   149,   150,   154,
+     158,   159,   163,   167,   181,   188,   189,   192,   193,   197,
+     198,   201,   202,   206,   207,   210,   211,   215,   216,   219,
+     220,   224,   225,   228,   229,   233,   239,   243,   252,   261,
+     270,   279,   284,   288,   296,   300,   304,   309,   313,   320,
+     324,   329,   333,   340,   343,   350,   354,   358,   362,   366,
+     373,   377,   381,   388,   393,   392,   401,   405,   412,   417
 };
 #endif
 
@@ -575,11 +593,11 @@ static const char *const yytname[] =
   "TOK_ENTITY", "TOK_DEFAULT", "TOK_NUMBER", "TOK_MAX_RATE",
   "TOK_DUMP_DIR", "TOK_LOGFILE", "TOK_QOS", "TOK_FROM", "TOK_TO",
   "TOK_ROUTE", "TOK_PVC", "'{'", "'}'", "$accept", "all", "global",
-  "local", "item", "entity", "@1", "opt_options", "options", "option",
+  "local", "item", "entity", "$@1", "opt_options", "options", "option",
   "sig", "sig_items", "saal", "saal_items", "io", "io_items", "debug",
   "debug_items", "policy", "policy_items", "sig_item", "saal_item",
   "io_item", "debug_item", "opt_trace_size", "level", "mode",
-  "policy_item", "@2", "action", "direction", 0
+  "policy_item", "$@2", "action", "direction", 0
 };
 #endif
 
@@ -743,9 +761,18 @@ static const yytype_uint8 yystos[] =
 
 /* Like YYERROR except do call yyerror.  This remains here temporarily
    to ease the transition to the new meaning of YYERROR, for GCC.
-   Once GCC version 2 has supplanted version 1, this can go.  */
+   Once GCC version 2 has supplanted version 1, this can go.  However,
+   YYFAIL appears to be in use.  Nevertheless, it is formally deprecated
+   in Bison 2.4.2's NEWS entry, where a plan to phase it out is
+   discussed.  */
 
 #define YYFAIL		goto yyerrlab
+#if defined YYFAIL
+  /* This is here to suppress warnings from the GCC cpp's
+     -Wunused-macros.  Normally we don't worry about that warning, but
+     some users do, and we want to make it easy for users to remove
+     YYFAIL uses, which will produce warnings from Bison 2.5.  */
+#endif
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
@@ -802,7 +829,7 @@ while (YYID (0))
    we won't break user code: when these are the locations we know.  */
 
 #ifndef YY_LOCATION_PRINT
-# if YYLTYPE_IS_TRIVIAL
+# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
 #  define YY_LOCATION_PRINT(File, Loc)			\
      fprintf (File, "%d.%d-%d.%d",			\
 	      (Loc).first_line, (Loc).first_column,	\
@@ -913,17 +940,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -957,11 +987,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1241,10 +1271,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1260,11 +1288,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1272,9 +1299,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1298,14 +1325,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1313,51 +1365,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1387,7 +1416,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1395,7 +1423,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1418,9 +1445,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1431,7 +1457,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1441,6 +1466,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1449,16 +1477,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1490,20 +1518,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1543,7 +1567,9 @@ yyreduce:
   switch (yyn)
     {
         case 6:
-#line 84 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 88 "cfg_y.y"
     {
 	    if (!curr_sig->uni)
 		curr_sig->uni =
@@ -1567,14 +1593,18 @@ yyreduce:
     break;
 
   case 7:
-#line 108 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 112 "cfg_y.y"
     {
 	    set_verbosity(NULL,(yyvsp[(2) - (2)].num));
 	}
     break;
 
   case 13:
-#line 120 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 124 "cfg_y.y"
     {
 	    SIG_ENTITY *sig,**walk;
 
@@ -1585,7 +1615,7 @@ yyreduce:
 	    for (sig = entities; sig; sig = sig->next)
 		if (atm_equal((struct sockaddr *) &sig->signaling_pvc,
 		  (struct sockaddr *) &(yyvsp[(2) - (2)].pvc),0,0))
-		    yyerror("duplicate PVC address %d.%d.%d",S_PVC(sig));
+		    yyerror("duplicate PVC address");
 	    curr_sig = alloc_t(SIG_ENTITY);
 	    *curr_sig = _entity;
 	    curr_sig->signaling_pvc = (yyvsp[(2) - (2)].pvc);
@@ -1596,28 +1626,36 @@ yyreduce:
     break;
 
   case 19:
-#line 151 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 155 "cfg_y.y"
     {
 	    enter_vpci(curr_sig,(yyvsp[(2) - (4)].num),(yyvsp[(4) - (4)].num));
 	}
     break;
 
   case 21:
-#line 156 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 160 "cfg_y.y"
     {
 	    curr_sig->sig_qos = (yyvsp[(1) - (1)].str);
 	}
     break;
 
   case 22:
-#line 160 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 164 "cfg_y.y"
     {
 	    curr_sig->max_rate = (yyvsp[(1) - (1)].num);
 	}
     break;
 
   case 23:
-#line 164 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 168 "cfg_y.y"
     {
 	     struct sockaddr_atmsvc addr;
 	     char *mask;
@@ -1634,14 +1672,18 @@ yyreduce:
     break;
 
   case 24:
-#line 178 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 182 "cfg_y.y"
     {
 	    add_route(curr_sig,NULL,0);
 	}
     break;
 
   case 45:
-#line 230 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 234 "cfg_y.y"
     {
 	    set_verbosity("UNI",(yyvsp[(2) - (2)].num));
 	    set_verbosity("KERNEL",(yyvsp[(2) - (2)].num));
@@ -1650,14 +1692,18 @@ yyreduce:
     break;
 
   case 46:
-#line 236 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 240 "cfg_y.y"
     {
 	    enter_vpci(curr_sig,(yyvsp[(2) - (4)].num),(yyvsp[(4) - (4)].num));
 	}
     break;
 
   case 47:
-#line 240 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 244 "cfg_y.y"
     {
 #if defined(UNI30) || defined(ALLOW_UNI30) || defined(DYNAMIC_UNI)
 	    if (curr_sig->uni & ~S_UNI31) yyerror("UNI mode is already set");
@@ -1669,7 +1715,9 @@ yyreduce:
     break;
 
   case 48:
-#line 249 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 253 "cfg_y.y"
     {
 #if defined(UNI31) || defined(ALLOW_UNI30) || defined(DYNAMIC_UNI)
 	    if (curr_sig->uni & ~S_UNI30) yyerror("UNI mode is already set");
@@ -1681,7 +1729,9 @@ yyreduce:
     break;
 
   case 49:
-#line 258 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 262 "cfg_y.y"
     {
 #if defined(UNI40) || defined(DYNAMIC_UNI)
 	    if (curr_sig->uni) yyerror("UNI mode is already set");
@@ -1693,7 +1743,9 @@ yyreduce:
     break;
 
   case 50:
-#line 267 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 271 "cfg_y.y"
     {
 #if defined(Q2963_1) || defined(DYNAMIC_UNI)
 	    if (!(curr_sig->uni & S_UNI40)) yyerror("Incompatible UNI mode");
@@ -1705,7 +1757,9 @@ yyreduce:
     break;
 
   case 51:
-#line 276 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 280 "cfg_y.y"
     {
 	    yywarn("sig net  is obsolete, please use  sig mode net  instead");
 	    curr_sig->mode = sm_net;
@@ -1713,7 +1767,9 @@ yyreduce:
     break;
 
   case 53:
-#line 285 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 289 "cfg_y.y"
     {
 	    set_verbosity("SSCF",(yyvsp[(2) - (2)].num));
 	    set_verbosity("SSCOP",(yyvsp[(2) - (2)].num));
@@ -1721,21 +1777,27 @@ yyreduce:
     break;
 
   case 54:
-#line 293 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 297 "cfg_y.y"
     {
 	    set_verbosity("IO",(yyvsp[(2) - (2)].num));
 	}
     break;
 
   case 55:
-#line 297 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 301 "cfg_y.y"
     {
 	    curr_sig->signaling_pvc = (yyvsp[(2) - (2)].pvc);
 	}
     break;
 
   case 56:
-#line 301 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 305 "cfg_y.y"
     {
 	    yywarn("io pcr  is obsolete, please use  io qos  instead");
 	    curr_sig->sig_pcr = (yyvsp[(2) - (2)].num);
@@ -1743,28 +1805,36 @@ yyreduce:
     break;
 
   case 57:
-#line 306 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 310 "cfg_y.y"
     {
 	    curr_sig->sig_qos = (yyvsp[(1) - (1)].str);
 	}
     break;
 
   case 58:
-#line 310 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 314 "cfg_y.y"
     {
 	    curr_sig->max_rate = (yyvsp[(1) - (1)].num);
 	}
     break;
 
   case 59:
-#line 317 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 321 "cfg_y.y"
     {
 	    set_verbosity(NULL,(yyvsp[(2) - (2)].num));
 	}
     break;
 
   case 60:
-#line 321 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 325 "cfg_y.y"
     {
 	    dump_dir = (yyvsp[(1) - (1)].str);
 	    if (!trace_size) trace_size = DEFAULT_TRACE_SIZE;
@@ -1772,98 +1842,126 @@ yyreduce:
     break;
 
   case 61:
-#line 326 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 330 "cfg_y.y"
     {
 	    set_logfile((yyvsp[(1) - (1)].str));
 	}
     break;
 
   case 62:
-#line 330 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 334 "cfg_y.y"
     {
 	    trace_size = (yyvsp[(2) - (2)].num);
 	}
     break;
 
   case 63:
-#line 336 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 340 "cfg_y.y"
     {
 	    (yyval.num) = DEFAULT_TRACE_SIZE;
 	}
     break;
 
   case 64:
-#line 340 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 344 "cfg_y.y"
     {
 	    (yyval.num) = (yyvsp[(1) - (1)].num);
 	}
     break;
 
   case 65:
-#line 347 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 351 "cfg_y.y"
     {
 	    (yyval.num) = DIAG_DEBUG;
 	}
     break;
 
   case 66:
-#line 351 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 355 "cfg_y.y"
     {
 	    (yyval.num) = DIAG_INFO;
 	}
     break;
 
   case 67:
-#line 355 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 359 "cfg_y.y"
     {
 	    (yyval.num) = DIAG_WARN;
 	}
     break;
 
   case 68:
-#line 359 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 363 "cfg_y.y"
     {
 	    (yyval.num) = DIAG_ERROR;
 	}
     break;
 
   case 69:
-#line 363 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 367 "cfg_y.y"
     {
 	    (yyval.num) = DIAG_FATAL;
 	}
     break;
 
   case 70:
-#line 370 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 374 "cfg_y.y"
     {
 	    curr_sig->mode = sm_user;
 	}
     break;
 
   case 71:
-#line 374 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 378 "cfg_y.y"
     {
 	    curr_sig->mode = sm_net;
 	}
     break;
 
   case 72:
-#line 378 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 382 "cfg_y.y"
     {
 	    curr_sig->mode = sm_switch;
 	}
     break;
 
   case 73:
-#line 385 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 389 "cfg_y.y"
     {
 	    set_verbosity("POLICY",(yyvsp[(2) - (2)].num));
 	}
     break;
 
   case 74:
-#line 389 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 393 "cfg_y.y"
     {
 	    rule = alloc_t(RULE);
 	    rule->type = (yyvsp[(1) - (1)].num);
@@ -1871,21 +1969,27 @@ yyreduce:
     break;
 
   case 76:
-#line 398 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 402 "cfg_y.y"
     {
 	    (yyval.num) = ACL_ALLOW;
 	}
     break;
 
   case 77:
-#line 402 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 406 "cfg_y.y"
     {
 	    (yyval.num) = ACL_REJECT;
 	}
     break;
 
   case 78:
-#line 409 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 413 "cfg_y.y"
     {
 	    rule->type |= ACL_IN;
 	    put_address((yyvsp[(1) - (1)].str));
@@ -1893,7 +1997,9 @@ yyreduce:
     break;
 
   case 79:
-#line 414 "cfg_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 418 "cfg_y.y"
     {
 	    rule->type |= ACL_OUT;
 	    put_address((yyvsp[(1) - (1)].str));
@@ -1901,8 +2007,9 @@ yyreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1906 "cfg_y.c"
+
+/* Line 1464 of yacc.c  */
+#line 2013 "cfg_y.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1913,7 +2020,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1978,7 +2084,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1995,7 +2101,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2052,9 +2158,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -2079,7 +2182,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2090,7 +2193,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
