@@ -1,24 +1,22 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+/* A Bison parser, made by GNU Bison 2.4.3.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
-   Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2009, 2010 Free Software Foundation, Inc.
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +27,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +45,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.3"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,11 +53,68 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
+/* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
+#line 1 "ispl_y.y"
+
+/* isp.y - Internal Signaling Protocol test generator language */
+
+/* Written 1997,1998 by Werner Almesberger, EPFL-ICA */
+
+#if HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <stdlib.h>
+#include <stdio.h>
+#include <unistd.h>
+#include <string.h>
+#include <atm.h>
+#include <linux/atmsvc.h>
+
+#include "isp.h"
+
+
+static struct atmsvc_msg msg;
+
+int yylex (void);
+
+
+
+/* Line 189 of yacc.c  */
+#line 98 "ispl_y.c"
+
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef YYERROR_VERBOSE
+# undef YYERROR_VERBOSE
+# define YYERROR_VERBOSE 1
+#else
+# define YYERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
+
+
 /* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
@@ -135,74 +190,34 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 1 "ispl_y.y"
-
-/* isp.y - Internal Signaling Protocol test generator language */
-
-/* Written 1997,1998 by Werner Almesberger, EPFL-ICA */
-
-#if HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <stdlib.h>
-#include <stdio.h>
-#include <unistd.h>
-#include <string.h>
-#include <atm.h>
-#include <linux/atmsvc.h>
-
-#include "isp.h"
-
-
-static struct atmsvc_msg msg;
-
-
-
-
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
-
-/* Enabling verbose error messages.  */
-#ifdef YYERROR_VERBOSE
-# undef YYERROR_VERBOSE
-# define YYERROR_VERBOSE 1
-#else
-# define YYERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
-#endif
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 25 "ispl_y.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 26 "ispl_y.y"
+
     char *str;
     int num;
     enum atmsvc_msg_type type;
     VAR *var;
-}
-/* Line 187 of yacc.c.  */
-#line 193 "ispl_y.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 209 "ispl_y.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 206 "ispl_y.c"
+/* Line 264 of yacc.c  */
+#line 221 "ispl_y.c"
 
 #ifdef short
 # undef short
@@ -252,7 +267,7 @@ typedef short int yytype_int16;
 #define YYSIZE_MAXIMUM ((YYSIZE_T) -1)
 
 #ifndef YY_
-# if YYENABLE_NLS
+# if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
 #   define YY_(msgid) dgettext ("bison-runtime", msgid)
@@ -277,14 +292,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -365,9 +380,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -401,12 +416,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -503,12 +518,12 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,    47,    47,    48,    53,    52,    63,    62,    68,    72,
-      77,    87,    92,   106,   110,   114,   118,   122,   126,   130,
-     134,   138,   142,   146,   150,   154,   158,   164,   165,   169,
-     174,   182,   192,   194,   193,   200,   201,   205,   209,   214,
-     222,   226,   230,   234,   238,   242,   246,   250,   257,   258,
-     262,   271
+       0,    48,    48,    49,    54,    53,    64,    63,    69,    73,
+      78,    88,    93,   107,   111,   115,   119,   123,   127,   131,
+     135,   139,   143,   147,   151,   155,   159,   165,   166,   170,
+     175,   183,   193,   195,   194,   201,   202,   206,   210,   215,
+     223,   227,   231,   235,   239,   243,   247,   251,   258,   259,
+     263,   272
 };
 #endif
 
@@ -524,7 +539,7 @@ static const char *const yytname[] =
   "TOK_OKAY", "TOK_ERROR", "TOK_INDICATE", "TOK_CLOSE", "TOK_ITF_NOTIFY",
   "TOK_MODIFY", "TOK_SAP", "TOK_IDENTIFY", "TOK_TERMINATE", "TOK_EOL",
   "TOK_VALUE", "TOK_VARIABLE", "'='", "'?'", "$accept", "all", "command",
-  "@1", "@2", "type", "values", "value", "number", "opt_recv", "@3",
+  "$@1", "$@2", "type", "values", "value", "number", "opt_recv", "$@3",
   "fields", "field", "field_type", "help", "new_var", "old_var", 0
 };
 #endif
@@ -657,9 +672,18 @@ static const yytype_uint8 yystos[] =
 
 /* Like YYERROR except do call yyerror.  This remains here temporarily
    to ease the transition to the new meaning of YYERROR, for GCC.
-   Once GCC version 2 has supplanted version 1, this can go.  */
+   Once GCC version 2 has supplanted version 1, this can go.  However,
+   YYFAIL appears to be in use.  Nevertheless, it is formally deprecated
+   in Bison 2.4.2's NEWS entry, where a plan to phase it out is
+   discussed.  */
 
 #define YYFAIL		goto yyerrlab
+#if defined YYFAIL
+  /* This is here to suppress warnings from the GCC cpp's
+     -Wunused-macros.  Normally we don't worry about that warning, but
+     some users do, and we want to make it easy for users to remove
+     YYFAIL uses, which will produce warnings from Bison 2.5.  */
+#endif
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
@@ -716,7 +740,7 @@ while (YYID (0))
    we won't break user code: when these are the locations we know.  */
 
 #ifndef YY_LOCATION_PRINT
-# if YYLTYPE_IS_TRIVIAL
+# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
 #  define YY_LOCATION_PRINT(File, Loc)			\
      fprintf (File, "%d.%d-%d.%d",			\
 	      (Loc).first_line, (Loc).first_column,	\
@@ -827,17 +851,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -871,11 +898,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1155,10 +1182,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1174,11 +1199,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1186,9 +1210,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1212,14 +1236,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1227,51 +1276,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1301,7 +1327,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1309,7 +1334,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1332,9 +1356,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1345,7 +1368,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1355,6 +1377,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1363,16 +1388,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1404,20 +1429,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1457,7 +1478,9 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 53 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 54 "ispl_y.y"
     {
 	    memset(&msg,0,sizeof(msg));
 	    msg.type = (yyvsp[(2) - (2)].type);
@@ -1465,7 +1488,9 @@ yyreduce:
     break;
 
   case 5:
-#line 58 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 59 "ispl_y.y"
     {
 	    send_msg(&msg);
 	    if (verbose) dump_msg("SENT",&msg);
@@ -1473,7 +1498,9 @@ yyreduce:
     break;
 
   case 6:
-#line 63 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 64 "ispl_y.y"
     {
 	    recv_msg(&msg);
 	    if (!quiet) dump_msg("RECV",&msg);
@@ -1481,14 +1508,18 @@ yyreduce:
     break;
 
   case 8:
-#line 69 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 70 "ispl_y.y"
     {
 	    sleep((yyvsp[(2) - (2)].num));
 	}
     break;
 
   case 9:
-#line 73 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 74 "ispl_y.y"
     {
 	    assign((yyvsp[(2) - (4)].var),eval(vt_text,(yyvsp[(4) - (4)].str)));
 	    free((yyvsp[(4) - (4)].str));
@@ -1496,7 +1527,9 @@ yyreduce:
     break;
 
   case 10:
-#line 78 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 79 "ispl_y.y"
     {
 	    VAR *var;
 
@@ -1509,7 +1542,9 @@ yyreduce:
     break;
 
   case 11:
-#line 88 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 89 "ispl_y.y"
     {
 	    printf("%s\n",(yyvsp[(2) - (2)].str));
 	    free((yyvsp[(2) - (2)].str));
@@ -1517,7 +1552,9 @@ yyreduce:
     break;
 
   case 12:
-#line 93 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 94 "ispl_y.y"
     {
 	    fprintf(stderr,
 "Commands:\n"
@@ -1534,98 +1571,126 @@ yyreduce:
     break;
 
   case 14:
-#line 111 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 112 "ispl_y.y"
     {
 	    (yyval.type) = as_bind;
 	}
     break;
 
   case 15:
-#line 115 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 116 "ispl_y.y"
     {
 	    (yyval.type) = as_connect;
 	}
     break;
 
   case 16:
-#line 119 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 120 "ispl_y.y"
     {
 	    (yyval.type) = as_accept;
 	}
     break;
 
   case 17:
-#line 123 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 124 "ispl_y.y"
     {
 	    (yyval.type) = as_reject;
 	}
     break;
 
   case 18:
-#line 127 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 128 "ispl_y.y"
     {
 	    (yyval.type) = as_listen;
 	}
     break;
 
   case 19:
-#line 131 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 132 "ispl_y.y"
     {
 	    (yyval.type) = as_okay;
 	}
     break;
 
   case 20:
-#line 135 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 136 "ispl_y.y"
     {
 	    (yyval.type) = as_error;
 	}
     break;
 
   case 21:
-#line 139 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 140 "ispl_y.y"
     {
 	    (yyval.type) = as_indicate;
 	}
     break;
 
   case 22:
-#line 143 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 144 "ispl_y.y"
     {
 	    (yyval.type) = as_close;
 	}
     break;
 
   case 23:
-#line 147 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 148 "ispl_y.y"
     {
 	    (yyval.type) = as_itf_notify;
 	}
     break;
 
   case 24:
-#line 151 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 152 "ispl_y.y"
     {
 	    (yyval.type) = as_modify;
 	}
     break;
 
   case 25:
-#line 155 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 156 "ispl_y.y"
     {
 	    (yyval.type) = as_identify;
 	}
     break;
 
   case 26:
-#line 159 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 160 "ispl_y.y"
     {
 	    (yyval.type) = as_terminate;
 	}
     break;
 
   case 29:
-#line 170 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 171 "ispl_y.y"
     {
 	    cast((yyvsp[(3) - (3)].var),type_of((yyvsp[(1) - (3)].num)));
 	    store(&msg,(yyvsp[(1) - (3)].num),(yyvsp[(3) - (3)].var)->value);
@@ -1633,7 +1698,9 @@ yyreduce:
     break;
 
   case 30:
-#line 175 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 176 "ispl_y.y"
     {
 	    store(&msg,(yyvsp[(1) - (3)].num),eval(type_of((yyvsp[(1) - (3)].num)),(yyvsp[(3) - (3)].str)));
 	    free((yyvsp[(3) - (3)].str));
@@ -1641,7 +1708,9 @@ yyreduce:
     break;
 
   case 31:
-#line 183 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 184 "ispl_y.y"
     {
 	    char *end;
 
@@ -1652,21 +1721,27 @@ yyreduce:
     break;
 
   case 33:
-#line 194 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 195 "ispl_y.y"
     {
 	    if (msg.type != (yyvsp[(1) - (1)].type)) yyerror("wrong message type");
 	}
     break;
 
   case 37:
-#line 206 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 207 "ispl_y.y"
     {
 	    assign((yyvsp[(1) - (3)].var),pick(&msg,(yyvsp[(3) - (3)].num)));
 	}
     break;
 
   case 38:
-#line 210 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 211 "ispl_y.y"
     {
 	    cast((yyvsp[(3) - (3)].var),type_of((yyvsp[(1) - (3)].num)));
 	    check(pick(&msg,(yyvsp[(1) - (3)].num)),(yyvsp[(3) - (3)].var)->value);
@@ -1674,7 +1749,9 @@ yyreduce:
     break;
 
   case 39:
-#line 215 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 216 "ispl_y.y"
     {
 	    check(pick(&msg,(yyvsp[(1) - (3)].num)),eval(type_of((yyvsp[(1) - (3)].num)),(yyvsp[(3) - (3)].str)));
 	    free((yyvsp[(3) - (3)].str));
@@ -1682,63 +1759,81 @@ yyreduce:
     break;
 
   case 40:
-#line 223 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 224 "ispl_y.y"
     {
 	    (yyval.num) = F_VCC;
 	}
     break;
 
   case 41:
-#line 227 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 228 "ispl_y.y"
     {
 	    (yyval.num) = F_LISTEN_VCC;
 	}
     break;
 
   case 42:
-#line 231 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 232 "ispl_y.y"
     {
 	    (yyval.num) = F_REPLY;
 	}
     break;
 
   case 43:
-#line 235 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 236 "ispl_y.y"
     {
 	    (yyval.num) = F_PVC;
 	}
     break;
 
   case 44:
-#line 239 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 240 "ispl_y.y"
     {
 	    (yyval.num) = F_LOCAL;
 	}
     break;
 
   case 45:
-#line 243 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 244 "ispl_y.y"
     {
 	    (yyval.num) = F_QOS;
 	}
     break;
 
   case 46:
-#line 247 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 248 "ispl_y.y"
     {
 	    (yyval.num) = F_SVC;
 	}
     break;
 
   case 47:
-#line 251 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 252 "ispl_y.y"
     {
 	    (yyval.num) = F_SAP;
 	}
     break;
 
   case 50:
-#line 263 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 264 "ispl_y.y"
     {
 	    (yyval.var) = lookup((yyvsp[(1) - (1)].str));
 	    if ((yyval.var)) free((yyvsp[(1) - (1)].str));
@@ -1747,7 +1842,9 @@ yyreduce:
     break;
 
   case 51:
-#line 272 "ispl_y.y"
+
+/* Line 1464 of yacc.c  */
+#line 273 "ispl_y.y"
     {
 	    (yyval.var) = lookup((yyvsp[(1) - (1)].str));
 	    if (!(yyval.var)) yyerror("no such variable");
@@ -1756,8 +1853,9 @@ yyreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1761 "ispl_y.c"
+
+/* Line 1464 of yacc.c  */
+#line 1859 "ispl_y.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1768,7 +1866,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1833,7 +1930,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1850,7 +1947,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1907,9 +2004,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -1934,7 +2028,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1945,7 +2039,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
